@@ -78,7 +78,9 @@ mcmc0.imports <-
     thin = 1L,
     burn = 500L,
     freq = 500L,
-    invt = 1.0
+    invt = 1.0,
+    mc3_or_marg = TRUE,
+    xmax = 100000
   ) # takes seconds
 
 ## -----------------------------------------------------------------------------
